pub fn tree_diff(
before: &CompiledPolicy,
after: &CompiledPolicy,
) -> Option<String>Expand description
Produce a unified diff between two compiled policies, rendered as tree strings.
Returns None if the two policies produce identical tree output.